"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InternalServerError = exports.ValidationError = exports.MethodNotAllowedError = exports.NotFoundError = exports.UnauthorizedError = exports.BadRequestError = exports.APIError = void 0;
class APIError extends Error {
    constructor(message, statusCode, type, data) {
        super(message);
        this.message = message;
        this.statusCode = statusCode;
        this.type = type;
        this.data = data;
    }
    toJSON() {
        return Object.assign({ message: this.message, type: this.type }, this.data);
    }
}
exports.APIError = APIError;
class BadRequestError extends APIError {
    constructor(message, type, data) {
        super(message || 'Bad Request', 400, type || 'E_BAD_REQUEST', data);
    }
}
exports.BadRequestError = BadRequestError;
class UnauthorizedError extends APIError {
    constructor(message, type, data) {
        super(message || 'Unauthorized', 401, type || 'E_UNAUTHORIZED', data);
    }
}
exports.UnauthorizedError = UnauthorizedError;
class NotFoundError extends APIError {
    constructor(message, type, data) {
        super(message || 'Not Found', 404, type || 'E_NOT_FOUND', data);
    }
}
exports.NotFoundError = NotFoundError;
class MethodNotAllowedError extends APIError {
    constructor(message, type, data) {
        super(message || 'Method Not Allowed', 405, type || 'E_METHOD_NOT_ALLOWED', data);
    }
}
exports.MethodNotAllowedError = MethodNotAllowedError;
class ValidationError extends APIError {
    constructor(message, type, data) {
        super(message || 'Unprocessable Entity', 422, type || 'E_UNPROCESSABLE_ENTITY', data);
    }
}
exports.ValidationError = ValidationError;
class InternalServerError extends APIError {
    constructor(message, type, data) {
        super(message || 'Internal Server Error', 500, type || 'E_INTERNAL_SERVER_ERROR', data);
    }
}
exports.InternalServerError = InternalServerError;
//# sourceMappingURL=errors.js.map