import { Dispatch, FormEvent, MutableRefObject, SetStateAction } from 'react';
export declare type Value = string | boolean | number;
export declare type Validation = string | undefined;
export declare type Rule = (value: Value, values: Record<string, Value>) => Validation;
export declare type Rules = {
    [key: string]: Rule[];
};
export declare const rules: {
    required: (message?: string) => Rule;
    email: (message?: string) => Rule;
    matches: (regex: RegExp, message: string) => Rule;
    matchesValue: (matcher: string | ((values: Record<string, Value>) => Value), message: string) => Rule;
    requiredIf: (predicate: (values: Record<string, Value>) => boolean, message: string) => Rule;
};
export declare type Blurred = Record<string, boolean>;
export declare type Error = {
    name: string;
    message: string;
};
export declare type Context = {
    rules: MutableRefObject<Rules>;
    values: any;
    errors: Error[];
    blurred: Blurred;
    options: FormOptions;
    isSubmitting: boolean;
    hasSubmitted: boolean;
    setErrors: Dispatch<SetStateAction<Error[]>>;
    setBlurred: Dispatch<SetStateAction<Blurred>>;
    hasBlurred: (name: string) => any;
    updateValue: (name: string, value: Value) => any;
    handleSubmit: (event: FormEvent) => void | Promise<void>;
};
export declare const FormContext: import("react").Context<Context>;
export declare const FormProvider: import("react").Provider<Context>;
export declare const FormConsumer: import("react").Consumer<Context>;
export declare type UseForm<Values = Record<string, Value>> = {
    onSubmit: (values: Values) => void | Promise<void>;
    values?: Values;
    options?: FormOptions;
};
export declare type FormOptions = {
    validateOnBlur?: boolean;
};
export declare const useForm: <Values extends Record<string, Value>>({ onSubmit, values: initialValues, options, }: UseForm<Values>) => {
    rules: MutableRefObject<Rules>;
    values: Values;
    errors: Error[];
    blurred: Blurred;
    isSubmitting: boolean;
    hasSubmitted: boolean;
    options: FormOptions;
    setValues: Dispatch<SetStateAction<Values>>;
    setErrors: Dispatch<SetStateAction<Error[]>>;
    setBlurred: Dispatch<SetStateAction<Blurred>>;
    hasBlurred: (name: string) => void;
    updateValue: (name: string, value: Value) => void;
    handleSubmit: (event: FormEvent) => Promise<void>;
};
export declare type UseField = {
    name: string;
    value: Value;
    onChange?: (value: Value) => void;
    rules?: Rule[];
};
export declare const useField: ({ name, value: defaultValue, onChange, rules: fieldRules }: UseField) => {
    handleBlur: () => void;
    handleChange: (value: Value) => void;
    value: any;
    values: any;
    errors: string[];
};
